import sys
import readline
import cmd
import shlex

class Console(cmd.Cmd):
    def __init__(self, modes, mode = "films"):
        cmd.Cmd.__init__(self)
        try:
            readline.read_history_file("history")
        except IOError:
            pass
        
        self.mode = mode
        self.modes = modes
    
    def postcmd(self, stop, line):
        readline.write_history_file("history")
    
    def do_mode(self, mode):
        if mode in self.modes:
            self.mode = mode
        else:
            print "Error, mode '%s' is unknown" % mode
    
    def do_play(self, path):
        player = self.modes[self.mode]
        if not player.play(path):
            print "%s: unable to play %s" % (self.mode, path)
    
    def do_pause(self, args):
        player = self.modes[self.mode]
        player.pause()
    
    def do_stop(self, args):
        player = self.modes[self.mode]
        player.stop()
    
    def do_continue(self, pattern):
        player = self.modes[self.mode]
        player.continue_last(pattern)

    def do_seek(self, step):
        player = self.modes[self.mode]
        player.seek(float(step))
    
    def do_position(self, pos):
        player = self.modes[self.mode]
        if len(pos) == 0:
            print player.position()
        else:
            player.position(float(pos))
    
    def do_next(self, args):
        player = self.modes[self.mode]
        player.next()
        print "Playing", player._url

    def do_prev(self, args):
        player = self.modes[self.mode]
        player.prev()
        print "Playing", player._url
    
    def do_notify(self, msg):
        player = self.modes[self.mode]
        player.notify(msg)
    
    def do_volume(self, val):
        player = self.modes[self.mode]
        
        if len(val) == 0:
            print "Volume", player.get_volume()
        else:
            if val[0] == "+":
                player.volume(int(val))
            elif val[0] == "-":
                player.volume(int(val))
            else:
                player.set_volume(int(val))
    
    def do_mute(self, val):
        player = self.modes[self.mode]
        player.mute()
    
    def do_exit(self, args):
        sys.exit(0)

